<?php namespace EscapeWork\Manager\Banners\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use View;
use Input;
use Redirect;
use Response;
use Config;
use App;

class BannerController extends ManagerController
{

    public function __construct()
    {
        $this->banner      = App::make('EscapeWork\Manager\Banners\Repositories\BannerRepository');
        $this->bannerGroup = App::make('EscapeWork\Manager\Banners\Repositories\BannerGroupRepository');

        # filters
        $this->enableDefaultFilters('banners');
    }

    /**
     * Listando os banners
     */
    public function index()
    {
        $query = $this->banner->with('group')->orderBy('order');

        if (Input::has('banner_group_id')) {
            $query->where('banner_group_id', '=', Input::get('banner_group_id'));
        }

        $view              = View::make(Config::get('manager-banners::views.banners.index'));
        $view->banners     = $query->get();
        $view->bannerGroup = $this->bannerGroup;

        return $view;
    }

    /**
     * Página pra inserção de um banner
     */
    public function create()
    {
        $this->banner->fill(Input::old());

        $view              = View::make(Config::get('manager-banners::views.banners.form'));
        $view->banner      = $this->banner;
        $view->bannerGroup = $this->bannerGroup;
        $view->edit        = false;

        return $view;
    }

    /**
     * Salvando no banco de dados
     */
    public function store()
    {
        $this->banner->fill(Input::all());

        if (! $this->banner->validate()) {
            return Redirect::route('manager.banners.create')
                    ->withInput()
                    ->with('errors', Banner::$messages);
        }

        if (! $this->banner->uploadBanner(Input::file('banner'))) {
            return Redirect::route('manager.banners.create')
                    ->withInput()
                    ->with('errors', Banner::$messages);
        }

        $this->banner->save();

        return Redirect::route('manager.banners.index')
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi inserido com sucesso!');
    }

    /**
     * Formulário pra editar
     */
    public function edit($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Redirect::route('manager.banners.index')
                    ->with('error', 'Banner não encontrado');
        }

        $this->banner->fill(Input::old());

        $view              = View::make(Config::get('manager-banners::views.banners.form'));
        $view->banner      = $this->banner;
        $view->bannerGroup = $this->bannerGroup;
        $view->edit        = true;

        return $view;
    }

    /**
     * Fazendo o update
     */
    public function update($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Redirect::route('manager.banners.index')
                    ->with('error', 'Banner não encontrado');
        }

        $this->banner->fill(Input::all());

        if (! $this->banner->validate()) {
            return Redirect::route('manager.banners.edit', $this->banner->id)
                    ->withInput()
                    ->with('errors', Banner::$messages);
        }

        $this->banner->uploadBanner(Input::file('banner'));
        $this->banner->save();

        return Redirect::route('manager.banners.index')
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi editado com sucesso!');
    }

    /**
     * Excluindo o banner
     */
    public function destroy($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Redirect::route('manager.banners.index')
                    ->with('error', 'Banner não encontrado');
        }

        $this->banner->delete();

        return Redirect::route('manager.banners.index')
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi excluído com sucesso!');
    }

    /**
     * Atualizando se banner está ativo ou não
     */
    public function updateActive($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Response::json(array(
                'error' => 'Banner não encontrado'
            ));
        }

        $this->banner->active = Input::get('active');
        $this->banner->save();

        return Response::json(array(
            'message' => 'O banner foi atualizado com sucesso'
        ));
    }

    /**
     * Atualizando a ordem do banner
     */
    public function updateOrder($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Response::json(array(
                'error' => 'Banner não encontrado'
            ));
        }

        $this->banner->order = Input::get('order');
        $this->banner->save();

        return Response::json(array(
            'message' => 'O banner foi atualizado com sucesso'
        ));
    }
}