@extends('manager::layouts.master')

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li><a href="{{ route('manager.banners.index') }}">Banners</a> <span class="divider">/</span></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Banners</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.banners.index') }}" class="btn"><i class="icon-arrow-left"></i> Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    {{ Msg::getAll() }}

    <form action="{{ !$edit ? route('manager.banners.store') : route('manager.banners.update', $banner->id) }}" method="post" id="form-banner" class="form-horizontal" enctype="multipart/form-data">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            @section('fields')
                <div class="control-group">
                    <label for="banner_group_id" class="control-label">Grupo</label>

                    <div class="controls">
                        <select name="banner_group_id" id="banner_group_id" required>
                            {{ $bannerGroup->HTMLOptions($banner->banner_group_id) }}
                        </select>
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="control-group">
                    <label for="title" class="control-label">Título</label>

                    <div class="controls">
                        <input type="text" name="title" id="title" class="input-xxlarge" value="{{ $banner->title }}" maxlength="255" autofocus />
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="control-group">
                    <label for="description" class="control-label">Descrição</label>

                    <div class="controls">
                        <textarea name="description" id="description" class="input-xxlarge" rows="4">{{ $banner->description }}</textarea>
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="control-group">
                    <label for="link" class="control-label">Link</label>

                    <div class="controls">
                        <div class="input-prepend">
                            <span class="add-on">http://</span>
                            <input type="text" name="link" id="link" class="input-xxlarge" value="{{ str_replace('http://', '', $banner->link) }}" maxlength="255" />
                        </div>
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="control-group">
                    <label for="link" class="control-label">Abrir o link</label>

                    <div class="controls">
                        <label class="radio inline">
                            <input type="radio" name="target" value="_self" {{ $banner->target != '_blank' ? 'checked="checked"' : null }} />
                            Na mesma janela
                        </label>

                        <label class="radio inline">
                            <input type="radio" name="target" value="_blank" {{ $banner->target == '_blank' ? 'checked="checked"' : null }} />
                            Em outra janela
                        </label>
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="control-group">
                    <label for="banner" class="control-label">Banner</label>

                    <div class="controls">
                        <input type="file" name="banner" id="banner" class="input-xxlarge {{ !$edit ? 'required' : null }}" accept="{{ implode(',', $banner->acceptedImages) }}" />

                        <span class="help-block">Apenas imagens <strong>jpg</strong> e <strong>png</strong>.</span>
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                @if (! is_null($banner->banner))
                    <div class="control-group">
                        <label class="control-label">Imagem Atual</label>

                        <div class="controls">
                            <img src="{{ asset($banner->getUrl() . '/thumb-' . $banner->banner) }}" alt="" style="width: 150px" />
                        </div><!-- .controls -->
                    </div><!-- .control-group -->
                @endif

                <div class="control-group">
                    <label for="expire_at" class="control-label">Banner expira em:</label>

                    <div class="controls">
                        <div class="input-append">
                            <input type="text" name="expire_at" id="expire_at" class="input-medium" value="{{ ! is_null($banner->expire_at) ? date('d/m/Y', strtotime($banner->expire_at)) : null }}" data-datepicker maxlength="10" />
                            <span class="add-on"><i class="icon-calendar"></i></span>
                        </div>

                        <span class="help-block">Se uma data for selecionada, o banner deixará de ser exibido após esta data.</span>
                    </div><!-- .controls -->
                </div><!-- .control-group -->
            @show
        </fieldset>

        <div class="form-actions">
            <input type="submit" class="btn btn-primary" value="Salvar" data-loading-text="Salvando..." />
            <a href="{{ route('manager.banners.index') }}" class="btn">Cancelar</a>
        </div><!-- .form-actions -->
    </form>
@stop

@section('scripts')
    @parent
    <script type="text/javascript" src="/packages/escapework/manager-banners/assets/js/banners/form.js"></script>
@stop
